.. _swh-model:

Software Heritage - Data model
==============================

Implementation of the :ref:`data-model` to archive source code artifacts.

.. toctree::
   :caption: Overview:
   :titlesonly:

   data-model
   persistent-identifiers
   cli
   /apidoc/swh.model
